@@ -1,3 +1,25 @@
+#
+# Basic GeneDesign libraries
+#
+
+=head1 NAME
+
+GeneDesign::Random
+
+=head1 VERSION
+
+Version 3.05
+
+=head1 DESCRIPTION
+
+  Random DNA Generators
+  
+=head1 AUTHOR
+
+Sarah Richardson <notadoctor@jhu.edu>.
+
+=cut
+
 package Bio::GeneDesign::Random;
 require Exporter;
 
@@ -7,18 +29,29 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
-$VERSION = 3.01;
+$VERSION = 3.05;
 
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(
   randDNA
+  $VERSION
 );
 
-%EXPORT_TAGS =  (all => [qw(randDNA)]);
+%EXPORT_TAGS =  (all => \@EXPORT_OK);
 
-################################################################################
-###########################                          ###########################
-################################################################################
+=head1 Functions
+
+=head2 randDNA()
+
+  takes a target length and an AT percentage and generates a random nucleotide
+  sequence, with or without stops in the first frame
+  in: nucleotide sequence length (scalar), 
+      AT percentage (0 <= scalar <= 100), 
+      stop codon prevention(0 stops, 1 no stops), 
+      codon table (hash reference)
+  out: nucleotide sequence (string)
+  
+=cut
 
 sub randDNA
 {
@@ -50,34 +83,6 @@ sub randDNA
 
 __END__
 
-=head1 NAME
-
-GeneDesign::Random
-
-=head1 VERSION
-
-Version 3.00
-
-=head1 DESCRIPTION
-
-  Random DNA Generators
-  
-=head1 Functions
-
-=head2 randDNA()
-
-  takes a target length and an AT percentage and generates a random nucleotide
-  sequence, with or without stops in the first frame
-  in: nucleotide sequence length (scalar), 
-      AT percentage (0 <= scalar <= 100), 
-      stop codon prevention(0 stops, 1 no stops), 
-      codon table (hash reference)
-  out: nucleotide sequence (string)
-  
-=head1 AUTHOR
-
-Sarah Richardson <notadoctor@jhu.edu>.
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2011, GeneDesign developers
